Class: Filterameter::Registries::SortRegistry
- Inherits:
-
SubRegistry
- Object
- SubRegistry
- Filterameter::Registries::SortRegistry
- Defined in:
- lib/filterameter/registries/sort_registry.rb
Overview
# Sort Registry
Class SortRegistry is a collection of the sorts. It captures the declarations when classes are loaded, then uses the injected SortFactory to build the sorts on demand as they are needed.
Instance Method Summary collapse
Methods inherited from SubRegistry
#add, #fetch, #initialize, #parameter_names
Constructor Details
This class inherits a constructor from Filterameter::Registries::SubRegistry
Instance Method Details
#sort_parameter_names ⇒ Object
10 11 12 |
# File 'lib/filterameter/registries/sort_registry.rb', line 10 def sort_parameter_names @declarations.keys end |